@@ -1,6 +1,6 @@
 package Net::CLI::Interact;
 BEGIN {
-  $Net::CLI::Interact::VERSION = '1.111500';
+  $Net::CLI::Interact::VERSION = '1.111530';
 }
 
 {
@@ -149,7 +149,7 @@ Net::CLI::Interact - Toolkit for CLI Automation
 
 =head1 VERSION
 
-version 1.111500
+version 1.111530
 
 =head1 PURPOSE
 
@@ -207,7 +207,9 @@ Reuseable device command phrasebooks
 If you're a new user, please read the
 L<Tutorial|Net::CLI::Interact::Manual::Tutorial>. There's also a
 L<Cookbook|Net::CLI::Interact::Manual::Cookbook> and a L<Phrasebook
-Listing|Net::CLI::Interact::Manual::Phrasebook>.
+Listing|Net::CLI::Interact::Manual::Phrasebook>. For a more complete worked
+example check out the L<Net::Appliance::Session> distribution, for which this
+module was written.
 
 =head1 INTERFACE
 
