@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Action;
 BEGIN {
-  $Net::CLI::Interact::Action::VERSION = '1.111500';
+  $Net::CLI::Interact::Action::VERSION = '1.111530';
 }
 
 use Moose;
@@ -15,7 +15,7 @@ has 'type' => (
 
 has 'value' => (
     is => 'ro',
-    isa => 'Str|RegexpRef|ArrayRef[RegexpRef]',
+    isa => 'Str|ArrayRef[RegexpRef]',
     required => 1,
 );
 
@@ -26,14 +26,6 @@ has 'no_ors' => (
     default => 0,
 );
 
-has 'is_lazy' => (
-    is => 'ro',
-    isa => 'Bool',
-    required => 0,
-    default => 0,
-    init_arg => 'lazy',
-);
-
 has 'continuation' => (
     is => 'rw',
     isa => 'Net::CLI::Interact::ActionSet',
@@ -62,6 +54,12 @@ has 'response_stash' => (
     required => 0,
 );
 
+has 'prompt_hit' => (
+    is => 'rw',
+    isa => 'RegexpRef',
+    required => 0,
+);
+
 sub BUILDARGS {
     my ($class, @rest) = @_;
     # accept single hash ref or naked hash
@@ -86,7 +84,7 @@ sub clone {
 # count the number of sprintf parameters used in the value
 sub num_params {
     my $self = shift;
-    return 0 if ref $self->value eq ref qr//;
+    return 0 if ref $self->value;
     # this tricksy little number comes from the Perl FAQ
     my $count = () = $self->value =~ m/(?<!%)%/g;
     return $count;
@@ -106,7 +104,7 @@ Net::CLI::Interact::Action - Sent data or matched response from connected device
 
 =head1 VERSION
 
-version 1.111500
+version 1.111530
 
 =head1 DESCRIPTION
 
@@ -143,13 +141,6 @@ Only applies to the C<send> kind. Whether to skip appending the I<output
 record separator> (newline) to the C<send> command when sent to the connected
 device.
 
-=head2 is_lazy
-
-Only applies to the C<match> kind, and records whether the user specified this
-Match as a regular expression reference (false, the default), or the name of a
-Match defined elsewhere (true). In the latter case, it can trigger
-L<Net::CLI::Interact> to assume the Prompt value has permanently changed.
-
 =head2 continuation
 
 Only applies to the C<send> kind. When response output is likely to be paged,
@@ -182,6 +173,12 @@ the matched prompt which ended the action. This slot is used by the C<match>
 action as it slurps output, but the content is then transferred over to the
 partner C<send> in the ActionSet.
 
+=head2 prompt_hit
+
+When a command is successfully issued, the response is terminated by a prompt.
+However that prompt can be one of a list, defined in the Action. This slot
+records the regular expression from that list which was actually matched.
+
 =head2 clone
 
 Returns a new Action, which is a shallow clone of the existing one. All the
