@@ -1,10 +1,11 @@
 package Net::CLI::Interact::Role::Prompt;
 BEGIN {
-  $Net::CLI::Interact::Role::Prompt::VERSION = '1.111500';
+  $Net::CLI::Interact::Role::Prompt::VERSION = '1.111530';
 }
 
 use Moose::Role;
 use Net::CLI::Interact::ActionSet;
+with 'Net::CLI::Interact::Role::FindMatch';
 
 has 'wake_up' => (
     is => 'rw',
@@ -28,7 +29,7 @@ has '_prompt' => (
 
 sub set_prompt {
     my ($self, $name) = @_;
-    $self->_prompt( $self->phrasebook->prompt($name)->first->value );
+    $self->_prompt( $self->phrasebook->prompt($name)->first->value->[0] );
 }
 
 sub last_prompt {
@@ -44,8 +45,9 @@ sub last_prompt_re {
 
 sub prompt_looks_like {
     my ($self, $name) = @_;
-    return ($self->last_prompt
-        =~ $self->phrasebook->prompt($name)->first->value);
+    return $self->find_match(
+        $self->last_prompt, $self->phrasebook->prompt($name)->first->value
+    );
 }
 
 # pump until any of the prompts matches the output buffer
@@ -59,9 +61,12 @@ sub find_prompt {
     eval {
         PUMPING: while (1) {
             $self->transport->pump;
+            $self->logger->log('dump', 'debug', "SEEN:\n". $self->transport->buffer);
             foreach my $prompt ($self->phrasebook->prompt_names) {
                 # prompts consist of only one match action
-                if ($self->transport->buffer =~ $self->phrasebook->prompt($prompt)->first->value) {
+                if ($self->find_match(
+                        $self->transport->buffer,
+                        $self->phrasebook->prompt($prompt)->first->value)) {
                     $self->logger->log('prompt', 'info', "hit, matches prompt $prompt");
                     $self->last_actionset(
                         Net::CLI::Interact::ActionSet->new({ actions => [
@@ -80,7 +85,8 @@ sub find_prompt {
     };
 
     if ($@ and $self->has_wake_up and $wake_up) {
-        $self->logger->log('prompt', 'info', "failed: [$@], sending WAKE_UP and trying again");
+        $self->logger->log('prompt', 'info',
+            "failed: [$@], sending WAKE_UP and trying again");
         $self->transport->put( $self->wake_up );
         $self->find_prompt;
     }
@@ -104,7 +110,7 @@ Net::CLI::Interact::Role::Prompt - Command-line prompt management
 
 =head1 VERSION
 
-version 1.111500
+version 1.111530
 
 =head1 DESCRIPTION
 
